@@ -328,67 +328,70 @@
 	@$db->updatequery("ALTER TABLE `prov` ADD `num_prefix` varchar(20) NOT NULL");
 	@$db->updatequery("ALTER TABLE `prov` ADD `num_postfix` varchar(20) NOT NULL");
 /*1.19.4*/
-        @$db->updatequery("ALTER TABLE `auto_ussd` ADD `sms_report_goip` int(11) NOT NULL");
-        @$db->updatequery("ALTER TABLE `auto_ussd` ADD `bal_delay` int(11) NOT NULL default '0'");
-        @$db->updatequery("ALTER TABLE  `system` ADD `session_time` int(11) NOT NULL default '24'");
-
+	@$db->updatequery("ALTER TABLE `auto_ussd` ADD `sms_report_goip` int(11) NOT NULL");
+	@$db->updatequery("ALTER TABLE `auto_ussd` ADD `bal_delay` int(11) NOT NULL default '0'");
+	@$db->updatequery("ALTER TABLE  `system` ADD `session_time` int(11) NOT NULL default '24'");
+	
 
 /*1.20.1*/
-        @$db->updatequery("ALTER TABLE `auto_ussd` ADD `re_step2_enable` tinyint(1) NOT NULL");
-        @$db->updatequery("ALTER TABLE `auto_ussd` ADD `re_step2_cmd` varchar(64) NOT NULL");
-        @$db->updatequery("ALTER TABLE `auto_ussd` ADD `re_step2_ok_r` varchar(64) character set utf8 NOT NULL");
+	@$db->updatequery("ALTER TABLE `auto_ussd` ADD `re_step2_enable` tinyint(1) NOT NULL");
+	@$db->updatequery("ALTER TABLE `auto_ussd` ADD `re_step2_cmd` varchar(64) NOT NULL");
+	@$db->updatequery("ALTER TABLE `auto_ussd` ADD `re_step2_ok_r` varchar(64) character set utf8 NOT NULL");
 
 /*1.20.2*/
-        @$db->updatequery("ALTER TABLE `auto_ussd` ADD `auto_reset_remain_enable` tinyint(1) NOT NULL");
+	@$db->updatequery("ALTER TABLE `auto_ussd` ADD `auto_reset_remain_enable` tinyint(1) NOT NULL");
 
-        @$db->updatequery("ALTER TABLE `system` ADD `disable_status` tinyint(1) NOT NULL default '0'");
+	@$db->updatequery("ALTER TABLE `system` ADD `disable_status` tinyint(1) NOT NULL default '0'");
 
-/*1.19.2-t1*/
+/*1.21.5 add set cell*/
 	
-	@$db->updatequery("CREATE TABLE IF NOT EXISTS `recharge_record` (
-  `id` int(11) NOT NULL auto_increment,
-  `num` varchar(32) NOT NULL,
-  `result` int(11) NOT NULL,
-  `re_sim_iccid` varchar(32) NOT NULL,
-  `goip_id` int(11) NOT NULL,
-  `date` timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
-  `re_group_id` int(11) NOT NULL,
-  `be_name` varchar(32) NOT NULL,
-  `re_name` varchar(32) NOT NULL,
-  PRIMARY KEY  (`id`),
-  KEY `num` (`num`,`result`,`re_sim_iccid`,`goip_id`,`date`,`re_group_id`)
-) ENGINE=MyISAM  DEFAULT CHARSET=latin1 AUTO_INCREMENT=1;");
-	@$db->updatequery("CREATE TABLE IF NOT EXISTS `recharge_group` (
-  `id` int(11) NOT NULL auto_increment,
-  `name` varchar(32) NOT NULL,
-  `type` int(11) NOT NULL default '0',
-  `default_count` int(11) NOT NULL,
-  `num_plan` varchar(64) NOT NULL,
-  `num` varchar(32) NOT NULL,
-  `content` varchar(160) character set utf8 NOT NULL,
-  `return_num` varchar(32) NOT NULL,
-  `ok_content` varchar(160) character set utf8 NOT NULL,
-  `fail_content` varchar(160) character set utf8 NOT NULL,
-  `num_bre` varchar(32) NOT NULL,
-  `num_aft` varchar(32) NOT NULL,
-  PRIMARY KEY  (`id`)
-) ENGINE=MyISAM  DEFAULT CHARSET=latin1 AUTO_INCREMENT=1;");
-	@$db->updatequery("ALTER TABLE `goip` ADD `re_group_id` int(11) NOT NULL");
-	@$db->updatequery("ALTER TABLE `goip` ADD `re_type` int(11) NOT NULL");
-	@$db->updatequery("ALTER TABLE `goip` ADD `re_remain_count` int(11) NOT NULL");
-	@$db->updatequery("ALTER TABLE `goip` ADD `re_limit_count` int(11) NOT NULL");
-	@$db->updatequery("ALTER TABLE `goip` ADD `re_ing` int(1) NOT NULL default '0'");
-	@$db->updatequery("ALTER TABLE  `goip` ADD INDEX (  `re_group_id` )");
-	@$db->updatequery("ALTER TABLE  `goip` ADD INDEX (  `re_type` )");
-	@$db->updatequery("ALTER TABLE  `goip` ADD INDEX (  `re_remain_count` )");
-	@$db->updatequery("ALTER TABLE  `goip` ADD INDEX (  `re_limit_count` )");
-
-	@$db->updatequery("ALTER TABLE `recharge_group` ADD `fixed_num` varchar(32) NOT NULL");
-	@$db->updatequery("ALTER TABLE `recharge_group` ADD `dynamic_num` varchar(32) NOT NULL");
-
-/*1.19.2-t3*/
-
-	@$db->updatequery("ALTER TABLE `message` ADD  `resend` int(11) NOT NULL default '0'");
+/*1.22 
+add 3-4 step USSD auto balance
+add chaeck receive USSD balance
+fixed bug of delete goip group
+*/
 	
+	@$db->updatequery("ALTER TABLE  `auto_ussd` ADD  `auto_ussd_step3` VARCHAR( 160 ) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL ,
+ADD  `auto_ussd_step3_start_r` VARCHAR( 160 ) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL ,
+ADD  `auto_ussd_step4` VARCHAR( 160 ) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL ,
+ADD  `auto_ussd_step4_start_r` VARCHAR( 160 ) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL ;");
+
+	@$db->updatequery("ALTER TABLE  `receive` ADD  `smscnum` VARCHAR( 32 ) NOT NULL ;");
+
+/*1.22.1 add doapi*/
+
+/*1.22.1 changed bal_limit to float*/
+	@$db->updatequery("ALTER TABLE  `auto_ussd` CHANGE  `bal_limit`  `bal_limit` FLOAT NOT NULL");
+
+/*1.23 add fixed time and remain recharge*/
+	@$db->updatequery("ALTER TABLE  `auto_ussd` ADD `recharge_con_type` int(11) NOT NULL default '0',
+ADD  `fixed_time` varchar(10) NOT NULL,
+ADD  `remain_limit` int(11) NOT NULL default '0',
+ADD  `remain_set` int(11) NOT NULL default '0',
+ADD  `fixed_next_time` int(10) unsigned NOT NULL;");
+        if(!$rs || $rs[0] < 119){
+                @$db->updatequery("update `system` set `version`='119'");
+                @$db->updatequery("ALTER TABLE  `auto_ussd` ADD INDEX (  `sms_report_goip` )");
+                @$db->updatequery("ALTER TABLE  `auto_ussd` ADD INDEX (  `recharge_con_type` )");
+	}
+
+	@$db->updatequery("ALTER TABLE `message` ADD `resend` int(11) NOT NULL default '0'");
+
+/*1.24.1 fixed bug of provider with ' */
+
+	@$db->updatequery("ALTER TABLE `goip` ADD `auto_num_c` int(1) NOT NULL default '0'");
+
+/*1.24.3 fixed bug of mysql when shceduler SMS*/
+/*1.24.3 fixed bug of call expiry*/
+/*1.24.4 fixed bug of imsi when init and doapi when value=0*/
+/*1.24.4 fixed bug of receive SMS to http */
+/*1.25 add senttime in receive SMS */
+	@$db->updatequery("ALTER TABLE `receive` ADD `senttime` DATETIME NOT NULL");
+
+/*1.25 fixed bug of cron SMS and &$ in resend.php */
 	echo "update done! <a href=''  target=_top>Return</a>";
+/*1.25-t1 modify ussd timeout from 10 to 20s */
+/*1.25-t2 modify ussd timeout from 20 to 30s */
+/*1.25-t3 modify ussd timeout from 30 to 60s */
+/*1.25-t4 send sms timeout (en page) from 5s to 15s */
 ?>
